@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.57'; # VERSION
 
 use 5.010;
 use strict;
@@ -213,14 +213,14 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.56 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-08-18.
+This document describes version 0.57 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-09-03.
 
 =head1 FUNCTIONS
 
 
 =head2 cmdline_src_file(%args) -> [status, msg, result, meta]
 
-{en_US This function has args with cmdline_src=file}.
+This function has args with cmdline_src=file.
 
 Arguments ('*' denotes required arguments):
 
@@ -246,7 +246,7 @@ Return value:  (any)
 
 =head2 cmdline_src_invalid_arg_type(%args) -> [status, msg, result, meta]
 
-{en_US This function has non-str/non-array arg with cmdline_src}.
+This function has non-str/non-array arg with cmdline_src.
 
 Arguments ('*' denotes required arguments):
 
@@ -270,7 +270,7 @@ Return value:  (any)
 
 =head2 cmdline_src_multi_stdin(%args) -> [status, msg, result, meta]
 
-{en_US This function has multiple args with cmdline_src stdin/stdin_or_files}.
+This function has multiple args with cmdline_src stdin/stdin_or_files.
 
 Arguments ('*' denotes required arguments):
 
@@ -296,11 +296,9 @@ Return value:  (any)
 
 =head2 cmdline_src_multi_stdin_line(%args) -> [status, msg, result, meta]
 
-{en_US This function has several stdin_line arguments}.
+This function has several stdin_line arguments.
 
-{en_US 
 And one also has its is_password property set to true.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -328,7 +326,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_array(%args) -> [status, msg, result, meta]
 
-{en_US This function has arg with cmdline_src=stdin}.
+This function has arg with cmdline_src=stdin.
 
 Arguments ('*' denotes required arguments):
 
@@ -352,7 +350,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_line(%args) -> [status, msg, result, meta]
 
-{en_US This function has a single stdin_line argument}.
+This function has a single stdin_line argument.
 
 Arguments ('*' denotes required arguments):
 
@@ -378,7 +376,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_file_array(%args) -> [status, msg, result, meta]
 
-{en_US This function has array arg with cmdline_src=stdin_or_file}.
+This function has array arg with cmdline_src=stdin_or_file.
 
 Arguments ('*' denotes required arguments):
 
@@ -402,7 +400,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_file_str(%args) -> [status, msg, result, meta]
 
-{en_US This function has str arg with cmdline_src=stdin_or_file}.
+This function has str arg with cmdline_src=stdin_or_file.
 
 Arguments ('*' denotes required arguments):
 
@@ -426,7 +424,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_files_array(%args) -> [status, msg, result, meta]
 
-{en_US This function has array arg with cmdline_src=stdin_or_files}.
+This function has array arg with cmdline_src=stdin_or_files.
 
 Arguments ('*' denotes required arguments):
 
@@ -450,7 +448,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_files_str(%args) -> [status, msg, result, meta]
 
-{en_US This function has str arg with cmdline_src=stdin_or_files}.
+This function has str arg with cmdline_src=stdin_or_files.
 
 Arguments ('*' denotes required arguments):
 
@@ -474,7 +472,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_str(%args) -> [status, msg, result, meta]
 
-{en_US This function has arg with cmdline_src=stdin}.
+This function has arg with cmdline_src=stdin.
 
 Arguments ('*' denotes required arguments):
 
@@ -498,7 +496,7 @@ Return value:  (any)
 
 =head2 cmdline_src_unknown(%args) -> [status, msg, result, meta]
 
-{en_US This function has arg with unknown cmdline_src value}.
+This function has arg with unknown cmdline_src value.
 
 Arguments ('*' denotes required arguments):
 
@@ -522,12 +520,10 @@ Return value:  (any)
 
 =head2 test_binary(%args) -> [status, msg, result, meta]
 
-{en_US Accept binary in stdin/file}.
+Accept binary in stdin/file.
 
-{en_US 
 This function is like the one in C<Perinci::Examples> but argument is accepted
 via C<stdin_or_files>.
-}
 
 Arguments ('*' denotes required arguments):
 
