@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.57'; # VERSION
 
 use 5.010;
 use strict;
@@ -170,7 +170,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.56 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-08-18.
+This document describes version 0.57 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2015-09-03.
 
 =head1 HOMEPAGE
 
@@ -202,16 +202,14 @@ the same terms as the Perl 5 programming language system itself.
 =head1 DESCRIPTION
 
 
-{en_US 
 This package contains functions that demonstrate streaming input/output.
-}
 
 =head1 FUNCTIONS
 
 
 =head2 hash_stream(%args) -> [status, msg, result, meta]
 
-{en_US This function produces a stream of hashes}.
+This function produces a stream of hashes.
 
 Arguments ('*' denotes required arguments):
 
@@ -235,7 +233,7 @@ Return value:  (hash)
 
 =head2 nat(%args) -> [status, msg, result, meta]
 
-{en_US This function produces a stream of natural numbers}.
+This function produces a stream of natural numbers.
 
 Arguments ('*' denotes required arguments):
 
@@ -259,7 +257,7 @@ Return value:  (int)
 
 =head2 square_input(%args) -> [status, msg, result, meta]
 
-{en_US This function squares its stream input}.
+This function squares its stream input.
 
 Arguments ('*' denotes required arguments):
 
@@ -283,7 +281,7 @@ Return value:  (float)
 
 =head2 wc(%args) -> [status, msg, result, meta]
 
-{en_US Count the number of lines/words/characters of input, like the "wc" command}.
+Count the number of lines/words/characters of input, like the "wc" command.
 
 Arguments ('*' denotes required arguments):
 
@@ -307,12 +305,10 @@ Return value:  (str)
 
 =head2 wc_keys(%args) -> [status, msg, result, meta]
 
-{en_US Count the number of keys of each hash}.
+Count the number of keys of each hash.
 
-{en_US 
 This is a simple demonstration of accepting a stream of hashes. In command-line
 application this will translate to JSON stream.
-}
 
 Arguments ('*' denotes required arguments):
 
