@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.57'; # VERSION
 
 our %SPEC;
 
@@ -50,7 +50,7 @@ Perinci::Examples::Tiny - Small examples
 
 =head1 VERSION
 
-This document describes version 0.56 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2015-08-18.
+This document describes version 0.57 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2015-09-03.
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,7 @@ benchmarking startup overhead of L<Perinci::CmdLine::Inline>-generated scripts.
 
 =head2 noop() -> [status, msg, result, meta]
 
-{en_US Do nothing}.
+Do nothing.
 
 No arguments.
 
@@ -80,7 +80,7 @@ Return value:  (any)
 
 =head2 odd_even(%args) -> [status, msg, result, meta]
 
-{en_US Print 'odd' or 'even' depending on the number}.
+Print 'odd' or 'even' depending on the number.
 
 Arguments ('*' denotes required arguments):
 
@@ -88,7 +88,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<number>* => I<int>
 
-{en_US Number to test}.
+Number to test.
 
 =back
 
